function energiePlot(l,m,T,phi,omega)
    % Die Funktion energiePlot berechnet die Gesamtenergie eines Pendels
    % zu verschiedenen Zeitpunkten und traegt die Energie in einem Diagramm
    % gegen die Zeit auf
    %
    % Verwendung: energiePlot(l, m, T, phi, omega)
    % Input:
    %  - l ist eine positive reelle Zahl, die die Laenge des Pendels angibt
    %  - m ist eine positive reelle Zahl, die die Masse des Pendels angibt
    %  - T ist ein Spaltenvektor, der ein geordnetes und aequidistantes
    %    Gitter von Zeitpunkten enthaelt
    %  - phi ist ein Spaltenvektor, der dieselbe Groesse wie T besitzt und
    %    zu jedem Zeitpunkt in T die zugehoerige Auslenkung des Pendels
    %    als Winkel angibt
    %  - omega ist ein Spaltenvektor, der diesselbe Groesse wie T besitzt
    %    und zu jedem Zeitpunkt in T die zugehoerige Winkelgeschwindigkeit
    %    des Pendels angibt

    
    g = 9.81; % Ortsfaktor
    
    % berechne potentielle, kinetische und Gesamt-Energie:
    EPot = -l*m*g * cos(phi);
    EKin = 1/2*m*l^2 * omega.^2;
    E = EPot + EKin;
    
    % Enerigeverlauf ueber die Zeit zeichnen: 
    plot(T,E);
    title('Gesamtenergie des Pendels') % Ueberschrift des Diagramms
    xlabel('Zeit') % x-Achsen-Beschriftung
    ylabel('Energie') % y-Achsen-Beschriftung
    
end