function phasenAnimation(l, T, phi, omega)
    % Die Funktion phasenAnimation gibt die Bewegung eines Pendels als
    % Animation im Phasenraum wieder und speichert diese Animation als 
    % avi-Video in der Datei 'phasenAnimation.avi'.
    % 
    % Verwendung: phasenAnimation(l, T, phi, omega)
    % Input:
    %  - l ist eine positive reelle Zahl, die die Laenge des Pendels angibt
    %  - T ist ein Spaltenvektor, der ein geordnetes und aequidistantes
    %    Gitter von Zeitpunkten enthaelt
    %  - phi ist ein Spaltenvektor, der dieselbe Groesse wie T besitzt und
    %    zu jedem Zeitpunkt in T die zugehoerige Auslenkung des Pendels
    %    als Winkel angibt
    %  - omega ist ein Spaltenvektor, der diesselbe Groesse wie T besitzt
    %    und zu jedem Zeitpunkt in T die zugehoerige Winkelgeschwindigkeit
    %    des Pendels angibt
   
    
    % Frame-Rate fuer Video berechnen:
    timeStep = T(2)-T(1); % hierfuer muss dass Zeit-Gitter aequidistant sein!
    framesPerSecond = 1/timeStep;
    
    % Benoetige Groesse des Koordinatensystems bestimmen:
    axisArray = [min(phi), max(phi), min(omega), max(omega)];
    
    % Graphik erzeugen:
    figure, set(gcf, 'Color','white')
    % Title hinzufuegen:
    title('Phasen-Raum eines Pendels')
    
    % Groesse des Koordinatensystems anpassen, so dass es fuer alle Frames
    % gleich gross ist:
    axis(axisArray);
    % Achsen beschriften:
    xlabel('phi')
    ylabel('omega')
    
    % Verhalten des axis-Objekts beim Plotten weiterer Graphik-Objekte
    % festlegen:
    set(gca, 'nextplot','replacechildren');
    
    % Avi-Datei-Objekt erzeugen:
    aviobj = avifile('phasenAnimation.avi', 'compression', 'Cinepak');
    aviobj.fps = framesPerSecond;
    aviobj.quality = 50;
    
    % Einzelne Frames erzeugen und dem Video hinzufuegen
    for k=1:length(T)
        % die vorherige Zeichnung loeschen
        cla(gca)
        
        % Phasendiagramm bis zum Zeitpunkt T(k) plotten:
        plot(phi(1:k), omega(1:k))
        hold on
        % Kringel hinzufuegen um die aktuelle Position zu verdeutlichen:
        plot(phi(k),omega(k),'o')
        
        % Beschriftung zur Laenge des Pendels und zum Startwinkel
        % hinzufuegen:
        beschriftung =  ['l = ', int2str(l), sprintf('\n'), '\phi_0= ', ...
            num2str(phi(1)/2/pi),' * 2\pi', sprintf('\n'), ...
            '\omega_0 = ', num2str(omega(1)/2/pi), ' * 2\pi'];
        text(0.97*axisArray(1)+0.03*axisArray(2), 0.90*axisArray(4) ...
            + 0.1*axisArray(3), beschriftung)
        
        % Momentane Graphik als Frame zum Video hinzufuegen
        aviobj = addframe(aviobj, getframe(gcf));
    end
    
    close(gcf) % Graphik wieder schlieen
    
    aviobj = close(aviobj); % Avi-Datei schlieen
    
    display('Avi-Datei wurde erstellt.') % Meldung an Benutzer
    
end